# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/feed_item_validation_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/feed_item_validation_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\034FeedItemValidationErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\nEgoogle/ads/googleads_v2/proto/errors/feed_item_validation_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\xe7\x19\n\x1b\x46\x65\x65\x64ItemValidationErrorEnum\"\xc7\x19\n\x17\x46\x65\x65\x64ItemValidationError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x14\n\x10STRING_TOO_SHORT\x10\x02\x12\x13\n\x0fSTRING_TOO_LONG\x10\x03\x12\x17\n\x13VALUE_NOT_SPECIFIED\x10\x04\x12(\n$INVALID_DOMESTIC_PHONE_NUMBER_FORMAT\x10\x05\x12\x18\n\x14INVALID_PHONE_NUMBER\x10\x06\x12*\n&PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY\x10\x07\x12#\n\x1fPREMIUM_RATE_NUMBER_NOT_ALLOWED\x10\x08\x12\x1a\n\x16\x44ISALLOWED_NUMBER_TYPE\x10\t\x12\x16\n\x12VALUE_OUT_OF_RANGE\x10\n\x12*\n&CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY\x10\x0b\x12-\n)CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING\x10\x0c\x12\x18\n\x14INVALID_COUNTRY_CODE\x10\r\x12\x12\n\x0eINVALID_APP_ID\x10\x0e\x12!\n\x1dMISSING_ATTRIBUTES_FOR_FIELDS\x10\x0f\x12\x13\n\x0fINVALID_TYPE_ID\x10\x10\x12\x19\n\x15INVALID_EMAIL_ADDRESS\x10\x11\x12\x15\n\x11INVALID_HTTPS_URL\x10\x12\x12\x1c\n\x18MISSING_DELIVERY_ADDRESS\x10\x13\x12\x1d\n\x19START_DATE_AFTER_END_DATE\x10\x14\x12 \n\x1cMISSING_FEED_ITEM_START_TIME\x10\x15\x12\x1e\n\x1aMISSING_FEED_ITEM_END_TIME\x10\x16\x12\x18\n\x14MISSING_FEED_ITEM_ID\x10\x17\x12#\n\x1fVANITY_PHONE_NUMBER_NOT_ALLOWED\x10\x18\x12$\n INVALID_REVIEW_EXTENSION_SNIPPET\x10\x19\x12\x19\n\x15INVALID_NUMBER_FORMAT\x10\x1a\x12\x17\n\x13INVALID_DATE_FORMAT\x10\x1b\x12\x18\n\x14INVALID_PRICE_FORMAT\x10\x1c\x12\x1d\n\x19UNKNOWN_PLACEHOLDER_FIELD\x10\x1d\x12.\n*MISSING_ENHANCED_SITELINK_DESCRIPTION_LINE\x10\x1e\x12&\n\"REVIEW_EXTENSION_SOURCE_INELIGIBLE\x10\x1f\x12\'\n#HYPHENS_IN_REVIEW_EXTENSION_SNIPPET\x10 \x12-\n)DOUBLE_QUOTES_IN_REVIEW_EXTENSION_SNIPPET\x10!\x12&\n\"QUOTES_IN_REVIEW_EXTENSION_SNIPPET\x10\"\x12\x1f\n\x1bINVALID_FORM_ENCODED_PARAMS\x10#\x12\x1e\n\x1aINVALID_URL_PARAMETER_NAME\x10$\x12\x17\n\x13NO_GEOCODING_RESULT\x10%\x12(\n$SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT\x10&\x12-\n)CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED\x10\'\x12 \n\x1cINVALID_PLACEHOLDER_FIELD_ID\x10(\x12\x13\n\x0fINVALID_URL_TAG\x10)\x12\x11\n\rLIST_TOO_LONG\x10*\x12\"\n\x1eINVALID_ATTRIBUTES_COMBINATION\x10+\x12\x14\n\x10\x44UPLICATE_VALUES\x10,\x12%\n!INVALID_CALL_CONVERSION_ACTION_ID\x10-\x12!\n\x1d\x43\x41NNOT_SET_WITHOUT_FINAL_URLS\x10.\x12$\n APP_ID_DOESNT_EXIST_IN_APP_STORE\x10/\x12\x15\n\x11INVALID_FINAL_URL\x10\x30\x12\x18\n\x14INVALID_TRACKING_URL\x10\x31\x12*\n&INVALID_FINAL_URL_FOR_APP_DOWNLOAD_URL\x10\x32\x12\x12\n\x0eLIST_TOO_SHORT\x10\x33\x12\x17\n\x13INVALID_USER_ACTION\x10\x34\x12\x15\n\x11INVALID_TYPE_NAME\x10\x35\x12\x1f\n\x1bINVALID_EVENT_CHANGE_STATUS\x10\x36\x12\x1b\n\x17INVALID_SNIPPETS_HEADER\x10\x37\x12\x1c\n\x18INVALID_ANDROID_APP_LINK\x10\x38\x12;\n7NUMBER_TYPE_WITH_CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY\x10\x39\x12\x1a\n\x16RESERVED_KEYWORD_OTHER\x10:\x12\x1b\n\x17\x44UPLICATE_OPTION_LABELS\x10;\x12\x1d\n\x19\x44UPLICATE_OPTION_PREFILLS\x10<\x12\x18\n\x14UNEQUAL_LIST_LENGTHS\x10=\x12\x1f\n\x1bINCONSISTENT_CURRENCY_CODES\x10>\x12*\n&PRICE_EXTENSION_HAS_DUPLICATED_HEADERS\x10?\x12.\n*ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION\x10@\x12%\n!PRICE_EXTENSION_HAS_TOO_FEW_ITEMS\x10\x41\x12\x15\n\x11UNSUPPORTED_VALUE\x10\x42\x12\x1c\n\x18INVALID_FINAL_MOBILE_URL\x10\x43\x12%\n!INVALID_KEYWORDLESS_AD_RULE_LABEL\x10\x44\x12\'\n#VALUE_TRACK_PARAMETER_NOT_SUPPORTED\x10\x45\x12*\n&UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE\x10\x46\x12\x18\n\x14INVALID_IOS_APP_LINK\x10G\x12,\n(MISSING_IOS_APP_LINK_OR_IOS_APP_STORE_ID\x10H\x12\x1a\n\x16PROMOTION_INVALID_TIME\x10I\x12\x39\n5PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF\x10J\x12>\n:PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT\x10K\x12%\n!TOO_MANY_DECIMAL_PLACES_SPECIFIED\x10L\x12\x1e\n\x1a\x41\x44_CUSTOMIZERS_NOT_ALLOWED\x10M\x12\x19\n\x15INVALID_LANGUAGE_CODE\x10N\x12\x18\n\x14UNSUPPORTED_LANGUAGE\x10O\x12\x1b\n\x17IF_FUNCTION_NOT_ALLOWED\x10P\x12\x1c\n\x18INVALID_FINAL_URL_SUFFIX\x10Q\x12#\n\x1fINVALID_TAG_IN_FINAL_URL_SUFFIX\x10R\x12#\n\x1fINVALID_FINAL_URL_SUFFIX_FORMAT\x10S\x12\x30\n,CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED\x10T\x12\'\n#ONLY_ONE_DELIVERY_OPTION_IS_ALLOWED\x10U\x12\x1d\n\x19NO_DELIVERY_OPTION_IS_SET\x10V\x12&\n\"INVALID_CONVERSION_REPORTING_STATE\x10W\x12\x14\n\x10IMAGE_SIZE_WRONG\x10X\x12+\n\'EMAIL_DELIVERY_NOT_AVAILABLE_IN_COUNTRY\x10Y\x12\'\n#AUTO_REPLY_NOT_AVAILABLE_IN_COUNTRY\x10Z\x12\x1a\n\x16INVALID_LATITUDE_VALUE\x10[\x12\x1b\n\x17INVALID_LONGITUDE_VALUE\x10\\\x12\x13\n\x0fTOO_MANY_LABELS\x10]\x12\x15\n\x11INVALID_IMAGE_URL\x10^\x12\x1a\n\x16MISSING_LATITUDE_VALUE\x10_\x12\x1b\n\x17MISSING_LONGITUDE_VALUE\x10`\x12\x15\n\x11\x41\x44\x44RESS_NOT_FOUND\x10\x61\x12\x1a\n\x16\x41\x44\x44RESS_NOT_TARGETABLE\x10\x62\x42\xf7\x01\n\"com.google.ads.googleads.v2.errorsB\x1c\x46\x65\x65\x64ItemValidationErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_FEEDITEMVALIDATIONERRORENUM_FEEDITEMVALIDATIONERROR = _descriptor.EnumDescriptor(
  name='FeedItemValidationError',
  full_name='google.ads.googleads.v2.errors.FeedItemValidationErrorEnum.FeedItemValidationError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING_TOO_SHORT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING_TOO_LONG', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE_NOT_SPECIFIED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DOMESTIC_PHONE_NUMBER_FORMAT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PHONE_NUMBER', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREMIUM_RATE_NUMBER_NOT_ALLOWED', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISALLOWED_NUMBER_TYPE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE_OUT_OF_RANGE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOMER_NOT_WHITELISTED_FOR_CALLTRACKING', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_COUNTRY_CODE', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_APP_ID', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_ATTRIBUTES_FOR_FIELDS', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TYPE_ID', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_EMAIL_ADDRESS', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_HTTPS_URL', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_DELIVERY_ADDRESS', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='START_DATE_AFTER_END_DATE', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_FEED_ITEM_START_TIME', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_FEED_ITEM_END_TIME', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_FEED_ITEM_ID', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VANITY_PHONE_NUMBER_NOT_ALLOWED', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_REVIEW_EXTENSION_SNIPPET', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_NUMBER_FORMAT', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DATE_FORMAT', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PRICE_FORMAT', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_PLACEHOLDER_FIELD', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_ENHANCED_SITELINK_DESCRIPTION_LINE', index=30, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REVIEW_EXTENSION_SOURCE_INELIGIBLE', index=31, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HYPHENS_IN_REVIEW_EXTENSION_SNIPPET', index=32, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE_QUOTES_IN_REVIEW_EXTENSION_SNIPPET', index=33, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUOTES_IN_REVIEW_EXTENSION_SNIPPET', index=34, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FORM_ENCODED_PARAMS', index=35, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_URL_PARAMETER_NAME', index=36, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_GEOCODING_RESULT', index=37, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT', index=38, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED', index=39, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PLACEHOLDER_FIELD_ID', index=40, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_URL_TAG', index=41, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIST_TOO_LONG', index=42, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ATTRIBUTES_COMBINATION', index=43, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_VALUES', index=44, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CALL_CONVERSION_ACTION_ID', index=45, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_WITHOUT_FINAL_URLS', index=46, number=46,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APP_ID_DOESNT_EXIST_IN_APP_STORE', index=47, number=47,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FINAL_URL', index=48, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TRACKING_URL', index=49, number=49,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FINAL_URL_FOR_APP_DOWNLOAD_URL', index=50, number=50,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIST_TOO_SHORT', index=51, number=51,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_USER_ACTION', index=52, number=52,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TYPE_NAME', index=53, number=53,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_EVENT_CHANGE_STATUS', index=54, number=54,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_SNIPPETS_HEADER', index=55, number=55,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ANDROID_APP_LINK', index=56, number=56,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NUMBER_TYPE_WITH_CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY', index=57, number=57,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESERVED_KEYWORD_OTHER', index=58, number=58,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_OPTION_LABELS', index=59, number=59,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_OPTION_PREFILLS', index=60, number=60,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNEQUAL_LIST_LENGTHS', index=61, number=61,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCONSISTENT_CURRENCY_CODES', index=62, number=62,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_EXTENSION_HAS_DUPLICATED_HEADERS', index=63, number=63,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION', index=64, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_EXTENSION_HAS_TOO_FEW_ITEMS', index=65, number=65,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_VALUE', index=66, number=66,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FINAL_MOBILE_URL', index=67, number=67,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_KEYWORDLESS_AD_RULE_LABEL', index=68, number=68,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE_TRACK_PARAMETER_NOT_SUPPORTED', index=69, number=69,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE', index=70, number=70,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_IOS_APP_LINK', index=71, number=71,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_IOS_APP_LINK_OR_IOS_APP_STORE_ID', index=72, number=72,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTION_INVALID_TIME', index=73, number=73,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF', index=74, number=74,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT', index=75, number=75,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_DECIMAL_PLACES_SPECIFIED', index=76, number=76,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_CUSTOMIZERS_NOT_ALLOWED', index=77, number=77,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_LANGUAGE_CODE', index=78, number=78,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_LANGUAGE', index=79, number=79,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IF_FUNCTION_NOT_ALLOWED', index=80, number=80,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FINAL_URL_SUFFIX', index=81, number=81,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TAG_IN_FINAL_URL_SUFFIX', index=82, number=82,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FINAL_URL_SUFFIX_FORMAT', index=83, number=83,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED', index=84, number=84,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONLY_ONE_DELIVERY_OPTION_IS_ALLOWED', index=85, number=85,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_DELIVERY_OPTION_IS_SET', index=86, number=86,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CONVERSION_REPORTING_STATE', index=87, number=87,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_SIZE_WRONG', index=88, number=88,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMAIL_DELIVERY_NOT_AVAILABLE_IN_COUNTRY', index=89, number=89,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTO_REPLY_NOT_AVAILABLE_IN_COUNTRY', index=90, number=90,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_LATITUDE_VALUE', index=91, number=91,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_LONGITUDE_VALUE', index=92, number=92,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_LABELS', index=93, number=93,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_IMAGE_URL', index=94, number=94,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_LATITUDE_VALUE', index=95, number=95,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_LONGITUDE_VALUE', index=96, number=96,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADDRESS_NOT_FOUND', index=97, number=97,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADDRESS_NOT_TARGETABLE', index=98, number=98,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=168,
  serialized_end=3439,
)
_sym_db.RegisterEnumDescriptor(_FEEDITEMVALIDATIONERRORENUM_FEEDITEMVALIDATIONERROR)


_FEEDITEMVALIDATIONERRORENUM = _descriptor.Descriptor(
  name='FeedItemValidationErrorEnum',
  full_name='google.ads.googleads.v2.errors.FeedItemValidationErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FEEDITEMVALIDATIONERRORENUM_FEEDITEMVALIDATIONERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=3439,
)

_FEEDITEMVALIDATIONERRORENUM_FEEDITEMVALIDATIONERROR.containing_type = _FEEDITEMVALIDATIONERRORENUM
DESCRIPTOR.message_types_by_name['FeedItemValidationErrorEnum'] = _FEEDITEMVALIDATIONERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedItemValidationErrorEnum = _reflection.GeneratedProtocolMessageType('FeedItemValidationErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMVALIDATIONERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.feed_item_validation_error_pb2'
  ,
  __doc__ = """Container for enum describing possible validation errors of a feed item.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.FeedItemValidationErrorEnum)
  ))
_sym_db.RegisterMessage(FeedItemValidationErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import campaign_shared_set_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__shared__set__pb2
from google.ads.google_ads.v2.proto.services import campaign_shared_set_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__shared__set__service__pb2


class CampaignSharedSetServiceStub(object):
  """Proto file describing the Campaign Shared Set service.

  Service to manage campaign shared sets.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCampaignSharedSet = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignSharedSetService/GetCampaignSharedSet',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__shared__set__service__pb2.GetCampaignSharedSetRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__shared__set__pb2.CampaignSharedSet.FromString,
        )
    self.MutateCampaignSharedSets = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignSharedSetService/MutateCampaignSharedSets',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__shared__set__service__pb2.MutateCampaignSharedSetsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__shared__set__service__pb2.MutateCampaignSharedSetsResponse.FromString,
        )


class CampaignSharedSetServiceServicer(object):
  """Proto file describing the Campaign Shared Set service.

  Service to manage campaign shared sets.
  """

  def GetCampaignSharedSet(self, request, context):
    """Returns the requested campaign shared set in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCampaignSharedSets(self, request, context):
    """Creates or removes campaign shared sets. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CampaignSharedSetServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCampaignSharedSet': grpc.unary_unary_rpc_method_handler(
          servicer.GetCampaignSharedSet,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__shared__set__service__pb2.GetCampaignSharedSetRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__shared__set__pb2.CampaignSharedSet.SerializeToString,
      ),
      'MutateCampaignSharedSets': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCampaignSharedSets,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__shared__set__service__pb2.MutateCampaignSharedSetsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__shared__set__service__pb2.MutateCampaignSharedSetsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.CampaignSharedSetService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import customer_label_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__label__pb2
from google.ads.google_ads.v1.proto.services import customer_label_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__label__service__pb2


class CustomerLabelServiceStub(object):
  """Proto file describing the Customer Label service.

  Service to manage labels on customers.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCustomerLabel = channel.unary_unary(
        '/google.ads.googleads.v1.services.CustomerLabelService/GetCustomerLabel',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__label__service__pb2.GetCustomerLabelRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__label__pb2.CustomerLabel.FromString,
        )
    self.MutateCustomerLabels = channel.unary_unary(
        '/google.ads.googleads.v1.services.CustomerLabelService/MutateCustomerLabels',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__label__service__pb2.MutateCustomerLabelsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__label__service__pb2.MutateCustomerLabelsResponse.FromString,
        )


class CustomerLabelServiceServicer(object):
  """Proto file describing the Customer Label service.

  Service to manage labels on customers.
  """

  def GetCustomerLabel(self, request, context):
    """Returns the requested customer-label relationship in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCustomerLabels(self, request, context):
    """Creates and removes customer-label relationships.
    Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CustomerLabelServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCustomerLabel': grpc.unary_unary_rpc_method_handler(
          servicer.GetCustomerLabel,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__label__service__pb2.GetCustomerLabelRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__label__pb2.CustomerLabel.SerializeToString,
      ),
      'MutateCustomerLabels': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCustomerLabels,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__label__service__pb2.MutateCustomerLabelsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__label__service__pb2.MutateCustomerLabelsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.CustomerLabelService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import mobile_device_constant_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_mobile__device__constant__pb2
from google.ads.google_ads.v2.proto.services import mobile_device_constant_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_mobile__device__constant__service__pb2


class MobileDeviceConstantServiceStub(object):
  """Proto file describing the mobile device constant service.

  Service to fetch mobile device constants.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetMobileDeviceConstant = channel.unary_unary(
        '/google.ads.googleads.v2.services.MobileDeviceConstantService/GetMobileDeviceConstant',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_mobile__device__constant__service__pb2.GetMobileDeviceConstantRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_mobile__device__constant__pb2.MobileDeviceConstant.FromString,
        )


class MobileDeviceConstantServiceServicer(object):
  """Proto file describing the mobile device constant service.

  Service to fetch mobile device constants.
  """

  def GetMobileDeviceConstant(self, request, context):
    """Returns the requested mobile device constant in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_MobileDeviceConstantServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetMobileDeviceConstant': grpc.unary_unary_rpc_method_handler(
          servicer.GetMobileDeviceConstant,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_mobile__device__constant__service__pb2.GetMobileDeviceConstantRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_mobile__device__constant__pb2.MobileDeviceConstant.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.MobileDeviceConstantService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import feed_item_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__pb2
from google.ads.google_ads.v2.proto.services import feed_item_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__service__pb2


class FeedItemServiceStub(object):
  """Proto file describing the FeedItem service.

  Service to manage feed items.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetFeedItem = channel.unary_unary(
        '/google.ads.googleads.v2.services.FeedItemService/GetFeedItem',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__service__pb2.GetFeedItemRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__pb2.FeedItem.FromString,
        )
    self.MutateFeedItems = channel.unary_unary(
        '/google.ads.googleads.v2.services.FeedItemService/MutateFeedItems',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__service__pb2.MutateFeedItemsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__service__pb2.MutateFeedItemsResponse.FromString,
        )


class FeedItemServiceServicer(object):
  """Proto file describing the FeedItem service.

  Service to manage feed items.
  """

  def GetFeedItem(self, request, context):
    """Returns the requested feed item in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateFeedItems(self, request, context):
    """Creates, updates, or removes feed items. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_FeedItemServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetFeedItem': grpc.unary_unary_rpc_method_handler(
          servicer.GetFeedItem,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__service__pb2.GetFeedItemRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__pb2.FeedItem.SerializeToString,
      ),
      'MutateFeedItems': grpc.unary_unary_rpc_method_handler(
          servicer.MutateFeedItems,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__service__pb2.MutateFeedItemsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_feed__item__service__pb2.MutateFeedItemsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.FeedItemService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.services import conversion_upload_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__upload__service__pb2


class ConversionUploadServiceStub(object):
  """Service to upload conversions.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.UploadClickConversions = channel.unary_unary(
        '/google.ads.googleads.v2.services.ConversionUploadService/UploadClickConversions',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__upload__service__pb2.UploadClickConversionsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__upload__service__pb2.UploadClickConversionsResponse.FromString,
        )
    self.UploadCallConversions = channel.unary_unary(
        '/google.ads.googleads.v2.services.ConversionUploadService/UploadCallConversions',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__upload__service__pb2.UploadCallConversionsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__upload__service__pb2.UploadCallConversionsResponse.FromString,
        )


class ConversionUploadServiceServicer(object):
  """Service to upload conversions.
  """

  def UploadClickConversions(self, request, context):
    """Processes the given click conversions.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UploadCallConversions(self, request, context):
    """Processes the given call conversions.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ConversionUploadServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'UploadClickConversions': grpc.unary_unary_rpc_method_handler(
          servicer.UploadClickConversions,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__upload__service__pb2.UploadClickConversionsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__upload__service__pb2.UploadClickConversionsResponse.SerializeToString,
      ),
      'UploadCallConversions': grpc.unary_unary_rpc_method_handler(
          servicer.UploadCallConversions,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__upload__service__pb2.UploadCallConversionsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_conversion__upload__service__pb2.UploadCallConversionsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.ConversionUploadService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/shopping_performance_view.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/shopping_performance_view.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\034ShoppingPerformanceViewProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\nGgoogle/ads/googleads_v1/proto/resources/shopping_performance_view.proto\x12!google.ads.googleads.v1.resources\x1a\x1cgoogle/api/annotations.proto\"0\n\x17ShoppingPerformanceView\x12\x15\n\rresource_name\x18\x01 \x01(\tB\x89\x02\n%com.google.ads.googleads.v1.resourcesB\x1cShoppingPerformanceViewProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_SHOPPINGPERFORMANCEVIEW = _descriptor.Descriptor(
  name='ShoppingPerformanceView',
  full_name='google.ads.googleads.v1.resources.ShoppingPerformanceView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.ShoppingPerformanceView.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=188,
)

DESCRIPTOR.message_types_by_name['ShoppingPerformanceView'] = _SHOPPINGPERFORMANCEVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ShoppingPerformanceView = _reflection.GeneratedProtocolMessageType('ShoppingPerformanceView', (_message.Message,), dict(
  DESCRIPTOR = _SHOPPINGPERFORMANCEVIEW,
  __module__ = 'google.ads.googleads_v1.proto.resources.shopping_performance_view_pb2'
  ,
  __doc__ = """Shopping performance view. Provides Shopping campaign statistics
  aggregated at several product dimension levels. Product dimension values
  from Merchant Center such as brand, category, custom attributes, product
  condition and product type will reflect the state of each dimension as
  of the date and time when the corresponding event was recorded.
  
  
  Attributes:
      resource_name:
          The resource name of the Shopping performance view. Shopping
          performance view resource names have the form:
          ``customers/{customer_id}/shoppingPerformanceView``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.ShoppingPerformanceView)
  ))
_sym_db.RegisterMessage(ShoppingPerformanceView)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/common/keyword_plan_common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import keyword_plan_competition_level_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__competition__level__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/common/keyword_plan_common.proto',
  package='google.ads.googleads.v2.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.commonB\026KeywordPlanCommonProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Common\312\002\036Google\\Ads\\GoogleAds\\V2\\Common\352\002\"Google::Ads::GoogleAds::V2::Common'),
  serialized_pb=_b('\n>google/ads/googleads_v2/proto/common/keyword_plan_common.proto\x12\x1egoogle.ads.googleads.v2.common\x1aHgoogle/ads/googleads_v2/proto/enums/keyword_plan_competition_level.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xca\x01\n\x1cKeywordPlanHistoricalMetrics\x12\x39\n\x14\x61vg_monthly_searches\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12o\n\x0b\x63ompetition\x18\x02 \x01(\x0e\x32Z.google.ads.googleads.v2.enums.KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelB\xf1\x01\n\"com.google.ads.googleads.v2.commonB\x16KeywordPlanCommonProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Common\xea\x02\"Google::Ads::GoogleAds::V2::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__competition__level__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_KEYWORDPLANHISTORICALMETRICS = _descriptor.Descriptor(
  name='KeywordPlanHistoricalMetrics',
  full_name='google.ads.googleads.v2.common.KeywordPlanHistoricalMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='avg_monthly_searches', full_name='google.ads.googleads.v2.common.KeywordPlanHistoricalMetrics.avg_monthly_searches', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='competition', full_name='google.ads.googleads.v2.common.KeywordPlanHistoricalMetrics.competition', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=437,
)

_KEYWORDPLANHISTORICALMETRICS.fields_by_name['avg_monthly_searches'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_KEYWORDPLANHISTORICALMETRICS.fields_by_name['competition'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__competition__level__pb2._KEYWORDPLANCOMPETITIONLEVELENUM_KEYWORDPLANCOMPETITIONLEVEL
DESCRIPTOR.message_types_by_name['KeywordPlanHistoricalMetrics'] = _KEYWORDPLANHISTORICALMETRICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeywordPlanHistoricalMetrics = _reflection.GeneratedProtocolMessageType('KeywordPlanHistoricalMetrics', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANHISTORICALMETRICS,
  __module__ = 'google.ads.googleads_v2.proto.common.keyword_plan_common_pb2'
  ,
  __doc__ = """Historical metrics.
  
  
  Attributes:
      avg_monthly_searches:
          Average monthly searches for the past 12 months.
      competition:
          The competition level for the query.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.KeywordPlanHistoricalMetrics)
  ))
_sym_db.RegisterMessage(KeywordPlanHistoricalMetrics)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



config = {
    "interfaces": {
        "google.ads.googleads.v1.services.AdGroupLabelService": {
            "retry_codes": {
                "idempotent": ["DEADLINE_EXCEEDED", "UNAVAILABLE"],
                "non_idempotent": []
            },
            "retry_params": {
                "default": {
                    "initial_retry_delay_millis": 5000,
                    "retry_delay_multiplier": 1.3,
                    "max_retry_delay_millis": 60000,
                    "initial_rpc_timeout_millis": 3600000,
                    "rpc_timeout_multiplier": 1.0,
                    "max_rpc_timeout_millis": 3600000,
                    "total_timeout_millis": 3600000
                }
            },
            "methods": {
                "GetAdGroupLabel": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default"
                },
                "MutateAdGroupLabels": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default"
                }
            }
        }
    }
}



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import geo_target_constant_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_geo__target__constant__pb2
from google.ads.google_ads.v2.proto.services import geo_target_constant_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_geo__target__constant__service__pb2


class GeoTargetConstantServiceStub(object):
  """Proto file describing the Geo target constant service.

  Service to fetch geo target constants.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetGeoTargetConstant = channel.unary_unary(
        '/google.ads.googleads.v2.services.GeoTargetConstantService/GetGeoTargetConstant',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_geo__target__constant__service__pb2.GetGeoTargetConstantRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_geo__target__constant__pb2.GeoTargetConstant.FromString,
        )
    self.SuggestGeoTargetConstants = channel.unary_unary(
        '/google.ads.googleads.v2.services.GeoTargetConstantService/SuggestGeoTargetConstants',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_geo__target__constant__service__pb2.SuggestGeoTargetConstantsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_geo__target__constant__service__pb2.SuggestGeoTargetConstantsResponse.FromString,
        )


class GeoTargetConstantServiceServicer(object):
  """Proto file describing the Geo target constant service.

  Service to fetch geo target constants.
  """

  def GetGeoTargetConstant(self, request, context):
    """Returns the requested geo target constant in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SuggestGeoTargetConstants(self, request, context):
    """Returns GeoTargetConstant suggestions by location name or by resource name.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_GeoTargetConstantServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetGeoTargetConstant': grpc.unary_unary_rpc_method_handler(
          servicer.GetGeoTargetConstant,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_geo__target__constant__service__pb2.GetGeoTargetConstantRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_geo__target__constant__pb2.GeoTargetConstant.SerializeToString,
      ),
      'SuggestGeoTargetConstants': grpc.unary_unary_rpc_method_handler(
          servicer.SuggestGeoTargetConstants,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_geo__target__constant__service__pb2.SuggestGeoTargetConstantsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_geo__target__constant__service__pb2.SuggestGeoTargetConstantsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.GeoTargetConstantService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/geo_target_constant.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import geo_target_constant_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_geo__target__constant__status__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/geo_target_constant.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\026GeoTargetConstantProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\nAgoogle/ads/googleads_v1/proto/resources/geo_target_constant.proto\x12!google.ads.googleads.v1.resources\x1a\x44google/ads/googleads_v1/proto/enums/geo_target_constant_status.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x80\x03\n\x11GeoTargetConstant\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x63ountry_code\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0btarget_type\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x62\n\x06status\x18\x07 \x01(\x0e\x32R.google.ads.googleads.v1.enums.GeoTargetConstantStatusEnum.GeoTargetConstantStatus\x12\x34\n\x0e\x63\x61nonical_name\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x83\x02\n%com.google.ads.googleads.v1.resourcesB\x16GeoTargetConstantProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_geo__target__constant__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GEOTARGETCONSTANT = _descriptor.Descriptor(
  name='GeoTargetConstant',
  full_name='google.ads.googleads.v1.resources.GeoTargetConstant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.GeoTargetConstant.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.GeoTargetConstant.id', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.GeoTargetConstant.name', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='google.ads.googleads.v1.resources.GeoTargetConstant.country_code', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_type', full_name='google.ads.googleads.v1.resources.GeoTargetConstant.target_type', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.GeoTargetConstant.status', index=5,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='canonical_name', full_name='google.ads.googleads.v1.resources.GeoTargetConstant.canonical_name', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=621,
)

_GEOTARGETCONSTANT.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GEOTARGETCONSTANT.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GEOTARGETCONSTANT.fields_by_name['country_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GEOTARGETCONSTANT.fields_by_name['target_type'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GEOTARGETCONSTANT.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_geo__target__constant__status__pb2._GEOTARGETCONSTANTSTATUSENUM_GEOTARGETCONSTANTSTATUS
_GEOTARGETCONSTANT.fields_by_name['canonical_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['GeoTargetConstant'] = _GEOTARGETCONSTANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GeoTargetConstant = _reflection.GeneratedProtocolMessageType('GeoTargetConstant', (_message.Message,), dict(
  DESCRIPTOR = _GEOTARGETCONSTANT,
  __module__ = 'google.ads.googleads_v1.proto.resources.geo_target_constant_pb2'
  ,
  __doc__ = """A geo target constant.
  
  
  Attributes:
      resource_name:
          The resource name of the geo target constant. Geo target
          constant resource names have the form:
          ``geoTargetConstants/{geo_target_constant_id}``
      id:
          The ID of the geo target constant.
      name:
          Geo target constant English name.
      country_code:
          The ISO-3166-1 alpha-2 country code that is associated with
          the target.
      target_type:
          Geo target constant target type.
      status:
          Geo target constant status.
      canonical_name:
          The fully qualified English name, consisting of the target's
          name and that of its parent and country.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.GeoTargetConstant)
  ))
_sym_db.RegisterMessage(GeoTargetConstant)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
